@@ -220,6 +220,7 @@ enum {
 #define MEDIA_FLAG_ICE_LITE_PEER		SHARED_FLAG_ICE_LITE_PEER
 #define MEDIA_FLAG_ICE_CONTROLLING		0x00200000
 #define MEDIA_FLAG_LOOP_CHECK			0x00400000
+#define MEDIA_FLAG_REORDER_FORCED		0x00800000
 #define MEDIA_FLAG_PTIME_OVERRIDE		0x01000000
 #define MEDIA_FLAG_RTCP_FB			SHARED_FLAG_RTCP_FB
 #define MEDIA_FLAG_GENERATOR			0x02000000
@@ -227,7 +228,6 @@ enum {
 #define MEDIA_FLAG_RTCP_GEN			0x08000000
 #define MEDIA_FLAG_ECHO				0x10000000
 #define MEDIA_FLAG_BLACKHOLE			0x20000000
-#define MEDIA_FLAG_REORDER_FORCED		0x40000000
 #define MEDIA_FLAG_AUDIO_PLAYER			0x80000000
 #define MEDIA_FLAG_LEGACY_OSRTP			SHARED_FLAG_LEGACY_OSRTP
 #define MEDIA_FLAG_LEGACY_OSRTP_REV		SHARED_FLAG_LEGACY_OSRTP_REV
@@ -767,7 +767,7 @@ struct call {
 	sockaddr_t		xmlrpc_callback;
 	endpoint_t		dtmf_log_dest;
 
-	unsigned int		redis_hosted_db;
+	int			redis_hosted_db;
 	atomic64		last_redis_update;
 
 	struct recording 	*recording;
